@@ -7,7 +7,7 @@ class Command(BaseInitCommand):
     action = 'configure'
     name = 'tasks'
 
-    def perform_init(self, app_config) -> List[str]:
+    def perform_init(self, app_config, *args, **options) -> List[str]:
         report = []
         report.extend(app_config.schedule_tasks())
         report.extend(app_config.initialize_subscribers())
